package com.bizmatics.mhfire.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.bizmatics.common.core.bean.CommonPage;
import com.bizmatics.mhfire.persistence.mapper.FireWaterMapper;
import com.bizmatics.mhfire.persistence.mapper.po.FireWaterPO;
import com.bizmatics.mhfire.service.FireWaterService;

import com.bizmatics.mhfire.service.vo.FireWaterStatisticsVO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.*;

/**
 * @author yq
 * @date 2021/5/27 16:16
 */
@Service
public class FireWaterServiceImpl implements FireWaterService {

    @Autowired
    private FireWaterMapper fireWaterMapper;
    @Override
    public FireWaterPO getOne(String id) {
        return enhanceFireWaterPo(fireWaterMapper.selectOne(id));
    }

    @Override
    public CommonPage<FireWaterPO> page(Integer current, Integer size, Date startTime, Date endTime) {
        List<FireWaterPO> list = new ArrayList<>();
        Page<Map<String, Object>> page = new Page<>(current, size);
        page = fireWaterMapper.page(page, startTime, endTime);
        page.getRecords().forEach(stringObjectMap -> list.add(enhanceFireWaterPo(stringObjectMap)));
        return new CommonPage<>(list, page.getTotal(), page.getSize(), page.getCurrent());
    }

    @Override
    public FireWaterStatisticsVO getFireWaterStatistics(Date startTime, Date endTime) {
        FireWaterStatisticsVO fireWaterStatisticsVO = new FireWaterStatisticsVO();
        fireWaterStatisticsVO.setMunicipalFireCode(
                fireWaterMapper.selectCountByWaterNature("消火栓","市政",null,startTime,endTime));
        fireWaterStatisticsVO.setCommunityFireCode(
                fireWaterMapper.selectCountByWaterNature("消火栓","社区",null,startTime,endTime));
        fireWaterStatisticsVO.setUnitFireCode(
                fireWaterMapper.selectCountByWaterNature("消火栓","单位",null,startTime,endTime));
        fireWaterStatisticsVO.setNaturalWater(
                fireWaterMapper.selectCountByWaterNature("天然水源",null,null,startTime,endTime));
        fireWaterStatisticsVO.setMunicipalWater(
                fireWaterMapper.selectCountByWaterNature(null,"市政",null,startTime,endTime));
        fireWaterStatisticsVO.setResidentWater(
                fireWaterMapper.selectCountByWaterNature(null,"居民",null,startTime,endTime));
        fireWaterStatisticsVO.setUnitWater(
                fireWaterMapper.selectCountByWaterNature(null,"单位",null,startTime,endTime));
        fireWaterStatisticsVO.setMunicipalGetWater(
                fireWaterMapper.selectCountByWaterNature(null,null,"市政",startTime,endTime));
        fireWaterStatisticsVO.setLandGetWater(
                fireWaterMapper.selectCountByWaterNature(null,null,"地上",startTime,endTime));
        return fireWaterStatisticsVO;
    }

    /**
     * map转换为unitpo
     * @param fireWaterMap
     * @return
     */
    public FireWaterPO enhanceFireWaterPo(Map<String,Object> fireWaterMap){
        FireWaterPO fireWaterPo = new FireWaterPO();
        fireWaterPo.setAddress(fireWaterMap.get("水源地址").toString());
        //TODO 责任人字段没有
        fireWaterPo.setDutyPerson(Optional.ofNullable(fireWaterMap.get("手机号")).orElse("").toString());
        //TODO 手机号字段没有
        fireWaterPo.setPhone(Optional.ofNullable(fireWaterMap.get("手机号")).orElse("").toString());
        fireWaterPo.setType(fireWaterMap.get("水源类型").toString());
        fireWaterPo.setJurisdictionalAgency(fireWaterMap.get("管辖机构名称").toString());
        fireWaterPo.setGetWaterType(fireWaterMap.get("取水形式").toString());
        //TODO 水源行政字段没有
        fireWaterPo.setWaterAdministrative(Optional.ofNullable(fireWaterMap.get("手机号")).orElse("").toString());
        fireWaterPo.setStatus(fireWaterMap.get("可用状态").toString());
        fireWaterPo.setWaterUnit(fireWaterMap.get("供水单位").toString());
        fireWaterPo.setWaterGage(fireWaterMap.get("管网压力").toString());
        return fireWaterPo;
    }
}
